@@ -24,7 +24,10 @@ sys.modules["FileProvider"] = mod = objc.ObjCLazyModule(
         "__path__": __path__,
         "__loader__": globals().get("__loader__", None),
     },
-    (_FileProvider, Foundation,),
+    (
+        _FileProvider,
+        Foundation,
+    ),
 )
 
 
