@@ -25,3 +25,6 @@ class TestNSFileProviderError(TestCase):
             FileProvider.NSFileProviderErrorNewerExtensionVersionFound, -2004
         )
         self.assertEqual(FileProvider.NSFileProviderErrorCannotSynchronize, -2005)
+        self.assertEqual(FileProvider.NSFileProviderErrorNonEvictableChildren, -2006)
+        self.assertEqual(FileProvider.NSFileProviderErrorUnsyncedEdits, -2007)
+        self.assertEqual(FileProvider.NSFileProviderErrorNonEvictable, -2008)
