@@ -4,6 +4,6 @@ import objc
 
 
 class TestNSFileProviderItemDecoration(TestCase):
-    @min_sdk_level("10.16")
-    def test_protocols(self):
+    @min_sdk_level("11.0")
+    def test_protocols11_0(self):
         objc.protocolNamed("NSFileProviderItemDecorating")
